@@ -2,7 +2,7 @@ import schedule
 import time
 import ast
 import os
-import json 
+import json
 import requests
 
 def get_data(urlDict):
@@ -19,13 +19,13 @@ def get_data(urlDict):
         )
         data = json.loads(response.text)
         # data = ast.literal_eval(json.dumps(data))
-        
+
         all_data = all_data + data.get("result", [])
     return all_data
 
 
 def create_mapping(data):
-    
+
     start_stages = {}
     success_stages = {}
     truncate_stages = {}
@@ -121,9 +121,9 @@ def work(metricConfig):
 
     if data:
 
-        start_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record["status"] == "started"}
-        success_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record["status"] == "success"}
-        truncate_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record["status"] in ["aborted","failed"]}
+        start_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record.get("status","").lower() == "started"}
+        success_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record.get("status","").lower() == "success"}
+        truncate_jobs = {record["jobId"]:record["time"] for record in data if record["type"] == "job" and record.get("status","").lower() in ["aborted","failed"]}
         
 
         start_stages, success_stages ,truncate_stages, start_tasks, success_tasks,truncate_tasks = create_mapping(data)
@@ -133,7 +133,7 @@ def work(metricConfig):
         final_tasks = []
         for record in data:
 
-            if record["type"] == "task" and record["status"] == "success":
+            if record["type"] == "task" and record.get("status","").lower() == "success":
                 if record["taskId"] in list((success_tasks.get(record["jobId"],{})).get(record["stageId"],{}).keys()):
                     localdict = {}
                     localdict["taskName"] = record["taskName"]
@@ -161,7 +161,7 @@ def work(metricConfig):
                     localdict["stageName"] = record["stageName"]
                     localdict["startTime"] = start_tasks.get(record["jobId"],{}).get(record["stageId"],{}).get(record["taskId"],{}).get("time",0)
                     localdict["endTime"] = truncate_tasks.get(record["jobId"],{}).get(record["stageId"],{}).get(record["taskId"],{}).get("time",0)
-                    localdict["status"] = record["status"]
+                    localdict["status"] = record.get("status","").lower()
                     localdict["time"] = localdict["endTime"] 
                     localdict["type"] = "task"    
                     localdict["duration"] = localdict["endTime"] - localdict["startTime"]
@@ -172,7 +172,7 @@ def work(metricConfig):
 
                     
             
-            if record["type"] == "stage" and record["status"] == "success":
+            if record["type"] == "stage" and record.get("status","").lower() == "success":
                 if record["stageId"] in list(success_stages.get(record["jobId"],{}).keys()):
                     localdict = {}
                     localdict["stageName"] = record["stageName"]
@@ -210,7 +210,7 @@ def work(metricConfig):
                             if localdict["endTime"] != 0 and localdict["startTime"] != 0:                       
                                 final_tasks.append(localdict)
                             
-            if record["type"] == "stage" and record["status"] in ["failed","aborted"]:
+            if record["type"] == "stage" and record.get("status","").lower() in ["failed","aborted"]:
                 if  record["stageId"] in list(truncate_stages.get(record["jobId"],{}).keys()):
                     localdict = {}
                     localdict["stageName"] = record["stageName"]
@@ -218,7 +218,7 @@ def work(metricConfig):
                     localdict["jobId"] = record["jobId"]
                     localdict["startTime"] = start_stages.get(record["jobId"],{}).get(record["stageId"],{}).get("time",0)
                     localdict["endTime"] = truncate_stages.get(record["jobId"],{}).get(record["stageId"],{}).get("time",0) 
-                    localdict["status"] = record["status"]
+                    localdict["status"] = record.get("status","").lower()
                     localdict["time"] = localdict["endTime"] 
                     localdict["type"] = record["type"]     
                     localdict["duration"] = localdict["endTime"] - localdict["startTime"]
@@ -240,7 +240,7 @@ def work(metricConfig):
                             localdict["jobName"] = record["jobName"]
                             localdict["startTime"] = value["time"]
                             localdict["endTime"] = truncate_stages.get(record["jobId"],{}).get(record["stageId"],{}).get("time",0)       
-                            localdict["status"] = record["status"]
+                            localdict["status"] = record.get("status","").lower()
                             localdict["time"] = localdict["endTime"] 
                             localdict["type"] = "task"    
                             localdict["duration"] = localdict["endTime"] - localdict["startTime"]
@@ -251,7 +251,7 @@ def work(metricConfig):
                                     
             if record["type"] == "job":
                 #calculate duration of job
-                if record["jobId"] in list(success_jobs.keys()) and record["status"] == "success":
+                if record["jobId"] in list(success_jobs.keys()) and record.get("status","").lower() == "success":
                     localdict = {}
                     localdict["jobName"] = record["jobName"]
                     localdict["jobId"] = record["jobId"]
@@ -335,7 +335,7 @@ def work(metricConfig):
                             localdict["jobName"] = record["jobName"]
                             localdict["startTime"] = value["time"]
                             localdict["endTime"] = truncate_jobs.get(record["jobId"], 0) 
-                            localdict["status"] = record["status"]
+                            localdict["status"] = record.get("status","").lower()
                             localdict["time"] = localdict["endTime"] 
                             localdict["type"] = "stage"   
                             localdict["duration"] = localdict["endTime"] - localdict["startTime"]
@@ -358,7 +358,7 @@ def work(metricConfig):
                                     localdict["jobName"] = record["jobName"]
                                     localdict["startTime"] = val["time"]
                                     localdict["endTime"] = truncate_jobs.get(record["jobId"], 0)    
-                                    localdict["status"] = record["status"]
+                                    localdict["status"] = record.get("status","").lower()
                                     localdict["time"] = localdict["endTime"] 
                                     localdict["type"] = "task"    
                                     localdict["duration"] = localdict["endTime"] - localdict["startTime"]
@@ -386,11 +386,11 @@ def work(metricConfig):
                 if not rec["jobId"] in list(success_jobs.keys()):
                     result.append(rec)
 
-        #print("unfinished_to_buffer : ",len(result))
-        #print("success_jobs       : ",len(final_jobs))
-        #print("success_stages     : ",len(final_stages))
-        #print("success_tasks      : ",len(final_tasks))
-        #print("\n")
+        # print("unfinished_to_buffer : ",len(result))
+        # print("success_jobs       : ",len(final_jobs))
+        # print("success_stages     : ",len(final_stages))
+        # print("success_tasks      : ",len(final_tasks))
+        # print("\n")
 
         
         with open(bufferPath, "w") as fl:
@@ -401,4 +401,3 @@ def work(metricConfig):
         return []
 
 
-
